@@ -2,6 +2,7 @@ import base64
 import binascii
 
 from django.conf import settings
+from django.utils.crypto import constant_time_compare
 
 from .compat import unquote_plus
 
@@ -55,7 +56,13 @@ def validate_request(request):
 
     username, password = ret
 
-    if settings.BASICAUTH_USERS.get(username) != password:
+    raw_pass = settings.BASICAUTH_USERS.get(username)
+    if raw_pass is None:
+        return False
+
+    # To avoid timing atacks
+    # https://security.stackexchange.com/questions/83660/simple-string-comparisons-not-secure-against-timing-attacks
+    if not constant_time_compare(raw_pass, password):
         return False
 
     request.META['REMOTE_USER'] = username
